summaryrefslogtreecommitdiffstats
path: root/kmobile/devices/skeleton/skeleton.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/devices/skeleton/skeleton.cpp')
-rw-r--r--kmobile/devices/skeleton/skeleton.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/kmobile/devices/skeleton/skeleton.cpp b/kmobile/devices/skeleton/skeleton.cpp
index e6b1d9c5..c027baae 100644
--- a/kmobile/devices/skeleton/skeleton.cpp
+++ b/kmobile/devices/skeleton/skeleton.cpp
@@ -35,24 +35,24 @@
K_EXPORT_COMPONENT_FACTORY( libkmobile_skeleton, KMobileSkeleton() )
/* createObject needs to be reimplemented by every KMobileDevice driver */
-TQObject *KMobileSkeleton::createObject( TQObject *parent, const char *name,
+TQObject *KMobileSkeleton::createObject( TQObject *tqparent, const char *name,
const char *, const TQStringList &args )
{
- return new KMobileSkeleton( parent, name, args );
+ return new KMobileSkeleton( tqparent, name, args );
}
/**
* The KDE skeleton mobile device driver.
*/
KMobileSkeleton::KMobileSkeleton(TQObject *obj, const char *name, const TQStringList &args )
: KMobileDevice(obj, name, args)
{
// set initial device info
setClassType( Phone );
- m_deviceName = i18n("LX-50-Moohoo Addressbook (Skeleton)");
- m_deviceRevision = "0.1";
+ m_tqdeviceName = i18n("LX-50-Moohoo Addressbook (Skeleton)");
+ m_tqdeviceRevision = "0.1";
setCapabilities( hasAddressBook | hasNotes );
}
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
{
}
-// connect the device and ask user to turn device on (if necessary)
-bool KMobileSkeleton::connectDevice(TQWidget *parent)
+// connect the tqdevice and ask user to turn tqdevice on (if necessary)
+bool KMobileSkeleton::connectDevice(TQWidget *tqparent)
{
- if (KMessageBox::Continue != KMessageBox::warningContinueCancel(parent,
- i18n("Please turn on your %1 on now and press continue to proceed.").arg(m_deviceName),
- m_deviceClassName ) )
+ if (KMessageBox::Continue != KMessageBox::warningContinueCancel(tqparent,
+ i18n("Please turn on your %1 on now and press continue to proceed.").arg(m_tqdeviceName),
+ m_tqdeviceClassName ) )
return false;
// connect it now...
m_connected = true;
return m_connected;
}
// disconnect the device and return true, if sucessful
bool KMobileSkeleton::disconnectDevice(TQWidget *)
{
m_connected = true;
return true;
}
// returns true, if this device is read-only (default: false)
bool KMobileSkeleton::isReadOnly() const
{
return true;
@@ -87,7 +87,7 @@ bool KMobileSkeleton::isReadOnly() const
// return a unique ID, e.g. the IMEI number of phones, or a serial number
// this String is used to have a unique identification for syncronisation.
-TQString KMobileSkeleton::deviceUniqueID()
+TQString KMobileSkeleton::tqdeviceUniqueID()
{
return TQString::fromLocal8Bit("SkElEtOn-123456789");
}
@@ -132,7 +132,7 @@ int KMobileSkeleton::readAddress( int index, KABC::Addressee &addr )
int KMobileSkeleton::storeAddress( int, const KABC::Addressee &, bool )
{
/* this is a read-only device */
return KIO::ERR_WRITE_ACCESS_DENIED;
}
@@ -157,7 +157,7 @@ int KMobileSkeleton::readNote( int index, TQString &note )
"Device Driver : %4\n"
"Device Revision: %5\n")
.arg(index).arg(index)
- .arg(deviceClassName()).arg(deviceName()).arg(revision());
+ .arg(tqdeviceClassName()).arg(tqdeviceName()).arg(revision());
return 0;
}
@@ -35,24 +35,24 @@
}
/**
- * The KDE skeleton mobile device driver.
+ * The KDE skeleton mobile tqdevice driver.
*/
KMobileSkeleton::KMobileSkeleton(TQObject *obj, const char *name, const TQStringList &args )
@@ -35,24 +35,24 @@
: KMobileDevice(obj, name, args)
{
- // set initial device info
+ // set initial tqdevice info
setClassType( Phone );
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
return m_connected;
}
-// disconnect the device and return true, if sucessful
+// disconnect the tqdevice and return true, if sucessful
bool KMobileSkeleton::disconnectDevice(TQWidget *)
{
@@ -60,26 +60,26 @@ KMobileSkeleton::~KMobileSkeleton()
return true;
}
-// returns true, if this device is read-only (default: false)
+// returns true, if this tqdevice is read-only (default: false)
bool KMobileSkeleton::isReadOnly() const
{
@@ -132,7 +132,7 @@ int KMobileSkeleton::readAddress( int index, KABC::Addressee &addr )
int KMobileSkeleton::storeAddress( int, const KABC::Addressee &, bool )
{
- /* this is a read-only device */
+ /* this is a read-only tqdevice */
return KIO::ERR_WRITE_ACCESS_DENIED;
}